/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */

/* Header file used by gSOAP (soapcpp2) to create stubs to interface to R-GMA
   Web Services. This header was created by running "wsdl2h" on each of the
   R-GMA WSDL files, then merging the results, to allow us to produce a
   single set of stubs to access all of the R-GMA services. I've made several
   manual changes throughout this file to improve the way it works: carefully
   check ALL of the comments if you intend to regenerate the file! */

/* gSOAP DIRECTIVES ***********************************************************/

//gsoapopt cw
//gsoap rgma schema namespace:    http://rgma.glite.org

/* WSDL TYPES *****************************************************************/

/* The enumerated values for StorageType, QueryType and SQLType MUST match
   the corresponding #defines in rgma.h, otherwise you must implement a
   conversion in rgma_soap_stubs.c. */

enum xsd__boolean {false_, true_};
enum rgma__StorageType {memory, file, database};
enum rgma__QueryType {latest, continuous, history, static_};
enum rgma__SQLType {integer, real, double_, timestamp, char_, varchar};

struct rgma__StringList
{
	int __sizestring;
	char **string;
};

struct rgma__Endpoint
{
	char *url;
};

/* The rgma__ResourceEndpoint structure currently matches the definition
   of RGMAResourceEndpoint in rgma.h. If it changes, you must implement a
   conversion in rgma_soap_stubs.c (for stub_Consumer_startDirected). */

struct rgma__ResourceEndpoint
{
	int resourceId;
	char *url;
};

/* The rgma__ResourceEndpointList contains a dynamic array. The
   __sizeresourceEndpoint element is internal to gSOAP - don't remove the
   __size prefix! I've also removed a level of indirection from the dynamic
   array as its entries can never be NULL. */

struct rgma__ResourceEndpointList
{
	int __sizeresourceEndpoint;
	struct rgma__ResourceEndpoint *resourceEndpoint;
};

struct rgma__ProducerProperties
{
	struct rgma__Storage *storage;
	enum xsd__boolean history;
	enum xsd__boolean latest;
	enum xsd__boolean ignoreSlowConsumers;
};

struct rgma__Storage
{
	enum rgma__StorageType type;
	char *location;
	char *userName;
	char *password;
};

struct rgma__QueryProperties
{
	enum rgma__QueryType type;
	int *timeInterval;
};

struct rgma__ColumnMetaData
{
	char *columnName;
	enum rgma__SQLType columnType;
	char *tableName;
};

/* Don't change the name of the __item field, it's internal to gSOAP (it's
   gSOAP's way of representing a complexType with simpleContent). The @enum
   is an attribute and false_ is the default value if it's not present. */

struct rgma__NullableString
{
	char *__item;
	@enum xsd__boolean null = false_;
};

/* The rgma__ResultSet contains a dynamic array (col). The __sizecol
   element is internal to gSOAP - don't remove the __size prefix! I've also
   removed a level of indirection from the dynamic array as its entries can
   never be NULL. */

struct rgma__NullableStringList
{
	int __sizecol;
	struct rgma__NullableString *col;
};

/* The rgma__ResultSet contains two dynamic arrays (columnMetadata and
   row). The __size* elements are internal to gSOAP - don't remove
   the __size prefix! I've also removed a level of indirection from the
   dynamic arrays, as their entries can never be NULL. */

struct rgma__ResultSet
{
	int __sizecolumnMetaData;
	struct rgma__ColumnMetaData *columnMetaData;
	int __sizerow;
	struct rgma__NullableStringList *row;
	struct rgma__RGMAWarning *warning;
};

struct rgma__RGMAWarning
{
	char *msg;
};

struct rgma__RGMAException
{
	char *errMsg;
	int errNo;
	char *trace; /* ignored in our API */
};

struct rgma__UnknownResourceException
{
	char *errMsg;
	int errNo;
};

/* WSDL OPERATIONS ************************************************************/

/* Resource Framework operations (common to all services). */

int rgma__setTerminationInterval(
	int resourceId,
	int terminationInterval,
	struct rgma__setTerminationIntervalResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__getTerminationInterval(
	int resourceId,
	struct rgma__getTerminationIntervalResponse
	{
		int getTerminationIntervalReturn;
	} *);

int rgma__showSignOfLife(
	int resourceId,
	struct rgma__showSignOfLifeResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__getVersion(
	int resourceId,
	struct rgma__getVersionResponse
	{
		char* getVersionReturn;
	} *);

int rgma__close(
	int resourceId,
	struct rgma__closeResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__destroy(
	int resourceId,
	struct rgma__destroyResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

/* Consumer Service operations. */

int rgma__createConsumer(
	int terminationInterval,
	char *selectStatement,
	struct rgma__QueryProperties *queryProperties,
	struct rgma__createConsumerResponse
	{
		struct rgma__ResourceEndpoint *createConsumerReturn;
	} *);

int rgma__start(
	int resourceId,
	int timeout,
	struct rgma__startResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__startDirected(
	int resourceId,
	int timeout,
	struct rgma__ResourceEndpointList *producers,
	struct rgma__startDirectedResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__isExecuting(
	int resourceId,
	struct rgma__isExecutingResponse
	{
		enum xsd__boolean isExecutingReturn;
	} *);

int rgma__abort(
	int resourceId,
	struct rgma__abortResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__hasAborted(
	int resourceId,
	struct rgma__hasAbortedResponse
	{
		enum xsd__boolean hasAbortedReturn;
	} *);

int rgma__count(
	int resourceId,
	struct rgma__countResponse
	{
		int countReturn;
	} *);

int rgma__pop(
	int resourceId,
	int maxCount,
	struct rgma__popResponse
	{
		struct rgma__ResultSet *popReturn;
	} *);

int rgma__popAll(
	int resourceId,
	struct rgma__popAllResponse
	{
		struct rgma__ResultSet *popAllReturn;
	} *);

/* Primary Producer Service operations. */

int rgma__createPrimaryProducer(
	int terminationInterval,
	struct rgma__ProducerProperties *producerProperties,
	struct rgma__StringList *voNames,
	struct rgma__createPrimaryProducerResponse
	{
		struct rgma__ResourceEndpoint *createPrimaryProducerReturn;
	} *);

/* This structure is shared with the Secondary Producer implementation. */

struct rgma__declareTableResponse
{
	void *emptyReturn;  /* (manually added) */
};

int rgma__declareTable(
	int resourceId,
	char *tableName,
	char *predicate,
	int historyRetentionPeriod,
	int latestRetentionPeriod,
	struct rgma__declareTableResponse *
	); /* manually altered */

/* This structure is shared with the Secondary Producer implementation. */

struct rgma__getHistoryRetentionPeriodResponse
{
	int getHistoryRetentionPeriodReturn;
};

int rgma__getHistoryRetentionPeriod(
	int resourceId,
	char *tableName,
	struct rgma__getHistoryRetentionPeriodResponse *
	); /* manually altered */

int rgma__getLatestRetentionPeriod(
	int resourceId,
	char *tableName,
	struct rgma__getLatestRetentionPeriodResponse
	{
		int getLatestRetentionPeriodReturn;
	} *);

int rgma__insert(
	int resourceId,
	char *insertStatement,
	struct rgma__insertResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

int rgma__insertList(
	int resourceId,
	struct rgma__StringList *insertStatements,
	struct rgma__insertListResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

/* Secondary Producer Service operations. */

int rgma__createSecondaryProducer(
	int terminationInterval,
	struct rgma__ProducerProperties *producerProperties,
	struct rgma__StringList *voNames,
	struct rgma__createSecondaryProducerResponse
	{
		struct rgma__ResourceEndpoint *createSecondaryProducerReturn;
	} *);

/* The trailing underscores on the next two functions are to distinguish
   them from the corresponding PrimaryProducer ones: they're stripped off
   by gSOAP in the SOAP message. It's an evil hack and only works because
   the functions in both services take the same response type. The only
   alternative is to add a level of indirection to the optional arguments
   (because gSOAP doesn't write NULL pointers to the SOAP message).

   Note: It would be nice to use namespace prefixes to get around this, but
   because all operations and data types in all R-GMA services are in the same
   namespace (http://rgma.glite.org), you would have to duplicate everything
   for each new namespace prefix (if you map two prefixes to the same namespace,
   gSOAP can't do the reverse mapping correctly when it deserializes the
   messages coming back from the server). */

int rgma__declareTable_(
	int resourceId,
	char *tableName,
	char *predicate,
	int historyRetentionPeriod,
	struct rgma__declareTableResponse *
        ); /* (manually altered) */

int rgma__getHistoryRetentionPeriod_(
	int resourceId,
	char *tableName,
	struct rgma__getHistoryRetentionPeriodResponse *
	); /* (manually altered) */

/* On-demand Producer Service operations. */

int rgma__createOnDemandProducer(
	int terminationInterval,
	char *uri,
	struct rgma__StringList *voNames,
	struct rgma__createOnDemandProducerResponse
	{
		struct rgma__ResourceEndpoint *createOnDemandProducerReturn;
	} *);

int rgma__declareStaticTable(
	int resourceId,
	char *tableName,
	char *predicate,
	struct rgma__declareStaticTableResponse
	{
		void *emptyReturn;  /* (manually added) */
	} *);

/* End of file. */
