/*
 *  Copyright (c) 2004 on behalf of the EU EGEE Project:
 *  The European Organization for Nuclear Research (CERN),
 *  Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *  Datamat Spa, Italy
 *  Centre National de la Recherche Scientifique (CNRS), France
 *  CS Systeme d'Information (CSSI), France
 *  Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *  Universiteit van Amsterdam (UvA), Netherlands
 *  University of Helsinki (UH.HIP), Finland
 *  University of Bergen (UiB), Norway
 *  Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 */


#ifndef RGMA_STUBS_H
#define RGMA_STUBS_H

/* This header is shared by all implementations of the stubs used by the R-GMA
   C API (rgma.c) to interface to R-GMA servlets/services. */

#include "rgma.h"

/* Stub status codes. */

#define STUB_SUCCESS 0
#define STUB_ERROR 1

/* Opaque structure to hold any static information for the stub environment:
   for the gSOAP interface, this includes the SOAP environment. */

typedef struct STUB_ENV_S STUB_ENV;


/* Servlet/service I/O functions. All of these I/O functions return
   STUB_SUCCESS on success and STUB_ERROR on failure. In the even of an error
   you can call one of the stub_get_error functions to find out what went
   wrong. */

extern int stub_createConsumer(int terminationInterval, const char *selectStatement, int queryType, int timeInterval, STUB_ENV **stub_envP, RGMAException *exceptionP);
extern int stub_createPrimaryProducer(int terminationInterval, int properties, int storageType, RGMAStorageLocation *storageLocation, STUB_ENV **stub_envP, RGMAException *exceptionP);
extern int stub_createSecondaryProducer(int terminationInterval, int properties, int storageType, RGMAStorageLocation *storageLocation, STUB_ENV **stub_envP, RGMAException *exceptionP);
extern int stub_createOnDemandProducer(int terminationInterval, const char *uri, STUB_ENV **stub_envP, RGMAException *exceptionP);
extern int stub_PrimaryProducer_declareTable(STUB_ENV *stub_env, const char *tableName, const char *predicate, int historyRetentionPeriod, int latestRetentionPeriod, RGMAException *exceptionP);
extern int stub_PrimaryProducer_insert(STUB_ENV *stub_env, const char *insertStatement, int latestRetentionPeriod, RGMAException *exceptionP);
extern int stub_PrimaryProducer_insertList(STUB_ENV *stub_env, int numInserts, char **insertStatements, int latestRetentionPeriod, RGMAException *exceptionP);
extern int stub_PrimaryProducer_listTupleStores(RGMATupleStoreList **tupleStoreListPP, RGMAException *exceptionP);
extern int stub_PrimaryProducer_dropTupleStore(const char *logicalName, RGMAException *exceptionP);
extern int stub_PrimaryProducer_getHistoryRetentionPeriod(STUB_ENV *stub_env, const char *tableName, int *historyRetentionPeriodP, RGMAException *exceptionP);
extern int stub_PrimaryProducer_getLatestRetentionPeriod(STUB_ENV *stub_env, const char *tableName, int *latestRetentionPeriodP, RGMAException *exceptionP);
extern int stub_SecondaryProducer_listTupleStores(RGMATupleStoreList **tupleStoreListPP, RGMAException *exceptionP);
extern int stub_SecondaryProducer_dropTupleStore(const char *logicalName, RGMAException *exceptionP);
extern int stub_SecondaryProducer_declareTable(STUB_ENV *stub_env, const char *tableName, const char *predicate, int historyRetentionPeriod, RGMAException *exceptionP);
extern int stub_SecondaryProducer_getHistoryRetentionPeriod(STUB_ENV *stub_env, const char *tableName, int *historyRetentionPeriodP, RGMAException *exceptionP);
extern int stub_OnDemandProducer_declareStaticTable(STUB_ENV *stub_env, const char *tableName, const char *predicate, RGMAException *exceptionP);
extern int stub_Consumer_start(STUB_ENV *stub_env, int timeout, RGMAException *exceptionP);
extern int stub_Consumer_startDirected(STUB_ENV *stub_env, int timeout, int numProducers, RGMAResourceEndpoint *producers, RGMAException *exceptionP);
/* isExecuting is deprecated */
extern int stub_Consumer_isExecuting(STUB_ENV *stub_env, int *isExecuting, RGMAException *exceptionP);
/* count is deprecated */
extern int stub_Consumer_count(STUB_ENV *stub_env, int *count, RGMAException *exceptionP);
extern int stub_Consumer_abort(STUB_ENV *stub_env, RGMAException *exceptionP);
extern int stub_Consumer_hasAborted(STUB_ENV *stub_env, int *hasAbortedP, RGMAException *exceptionP);
extern int stub_Consumer_pop(STUB_ENV *stub_env, int maxCount, RGMAResultSet **resultSetP, RGMAException *exceptionP);
extern int stub_getTerminationInterval(STUB_ENV *stub_env, int *terminationIntervalP, RGMAException *exceptionP);
extern int stub_showSignOfLife(STUB_ENV *stub_env, RGMAException *exceptionP);
extern int stub_close(STUB_ENV *stub_env, RGMAException *exceptionP);
extern int stub_destroy(STUB_ENV *stub_env, RGMAException *exceptionP);
extern int stub_Registry_createRegistry(const char *vdbName, const char *registryService, RGMAException *exceptionP);
extern int stub_Registry_destroyRegistry(const char *vdbName, const char *registryService, RGMAException *exceptionP);
extern int stub_Registry_getAllProducersForTable(const char *vdbName, const char *tableName, RGMAProducerTableEntryList **producerTableEntryListPP, RGMAException *exceptionP);
extern int stub_Schema_createSchema(const char *vdbName, const char *schemaService, RGMAException *exceptionP);
extern int stub_Schema_destroySchema(const char *vdbName, const char *schemaService, RGMAException *exceptionP);
extern int stub_Schema_createTable(const char *vdbName, const char *createTableStatement, int numRules, char **rules, RGMAException *exceptionP);
extern int stub_Schema_dropTable(const char *vdbName, const char *tableName, RGMAException *exceptionP);
extern int stub_Schema_createIndex(const char *vdbName, const char *createIndexStatement, RGMAException *exceptionP);
extern int stub_Schema_dropIndex(const char *vdbName, const char *indexName, RGMAException *exceptionP);
extern int stub_Schema_createView(const char *vdbName, const char *createViewStatement, int numRules, char **rules, RGMAException *exceptionP);
extern int stub_Schema_dropView(const char *vdbName, const char *viewName, RGMAException *exceptionP);
extern int stub_Schema_getAllTables(const char *vdbName, RGMAStringList **stringListPP, RGMAException *exceptionP);
extern int stub_Schema_getTableDefinition(const char *vdbName, const char *tableName, RGMATableDefinition **tableDefinitionPP, RGMAException *exceptionP);
extern int stub_Schema_getTableIndexes(const char *vdbName, const char *tableName, RGMAIndexList **indexListPP, RGMAException *exceptionP);
extern int stub_Schema_setAuthorizationRules(const char *vdbName, const char *tableName, int numRules, char **rules, RGMAException *exceptionP);
extern int stub_Schema_getAuthorizationRules(const char *vdbName, const char *tableName, RGMAStringList **tableAuthzPP, RGMAException *exceptionP);
extern int stub_setProperty(int service, const char *name, const char *parameter, const char *value, RGMAException *exceptionP);
extern int stub_getProperty(int service, const char *name, const char *parameter, char **valueP, RGMAException *exceptionP);
extern int stub_getVersion(int service, char **versionP, RGMAException *exceptionP);

/* The following functions are handled internally by the stub implementation
   (and so don't require a connection to an R-GMA servlet/service). */

extern void stub_free(STUB_ENV *stub_env);
extern int stub_recreateFromEndpoint(RGMAResourceEndpoint *endpointP, int resourceType, STUB_ENV **stub_envP, RGMAException *exceptionP);
extern int stub_getEndpoint(STUB_ENV *stub_env, RGMAResourceEndpoint **endpointPP, RGMAException *exceptionP);

#endif /* RGMA_STUBS_H */
